@@ -27,6 +27,7 @@
 
 #if TARGET_OS_IOS
 #import "VLCMLMedia+Podcast.h"
+#import "VLCMLMedia+isWatched.h"
 #endif
 
 #import "VLC-Swift.h"
@@ -80,6 +81,8 @@ NSString *const VLCPlaybackServicePlaybackDidMoveOnToNextItem = @"VLCPlaybackSer
 
     NSInteger _currentIndex;
     NSMutableArray *_shuffledOrder;
+
+    BOOL _openInMiniPlayer;
 }
 
 @end
@@ -785,7 +788,10 @@ NSString *const VLCPlaybackServicePlaybackDidMoveOnToNextItem = @"VLCPlaybackSer
                 _mediaPlayer.audio.passthrough = bValue;
             }
 #endif
-            [[NSNotificationCenter defaultCenter] postNotificationName:VLCPlaybackServicePlaybackDidStart object:self];
+            [[NSNotificationCenter defaultCenter] postNotificationName:VLCPlaybackServicePlaybackDidStart object:self userInfo:@{
+                kVLCPlayerOpenInMiniPlayer: @(_openInMiniPlayer)
+            }];
+            _openInMiniPlayer = NO;
         } break;
 
         case VLCMediaPlayerStatePlaying: {
@@ -840,12 +846,15 @@ NSString *const VLCPlaybackServicePlaybackDidMoveOnToNextItem = @"VLCPlaybackSer
 
     _mediaPlayerState = currentState;
 
-    if ([self.delegate respondsToSelector:@selector(mediaPlayerStateChanged:isPlaying:currentMediaHasTrackToChooseFrom:currentMediaHasChapters:forPlaybackService:)])
-        [self.delegate mediaPlayerStateChanged:currentState
-                                     isPlaying:_mediaPlayer.isPlaying
-              currentMediaHasTrackToChooseFrom:self.currentMediaHasTrackToChooseFrom
-                       currentMediaHasChapters:self.currentMediaHasChapters
-                         forPlaybackService:self];
+    if ([self.delegate respondsToSelector:@selector(mediaPlayerStateChanged:isPlaying:currentMediaHasTrackToChooseFrom:currentMediaHasChapters:forPlaybackService:)]) {
+        dispatch_async(dispatch_get_main_queue(), ^{
+            [self.delegate mediaPlayerStateChanged:currentState
+                                         isPlaying:self->_mediaPlayer.isPlaying
+                  currentMediaHasTrackToChooseFrom:self.currentMediaHasTrackToChooseFrom
+                           currentMediaHasChapters:self.currentMediaHasChapters
+                                forPlaybackService:self];
+        });
+    }
 
     dispatch_async(dispatch_get_main_queue(), ^{
         [self setNeedsMetadataUpdate];
@@ -1361,17 +1370,24 @@ NSString *const VLCPlaybackServicePlaybackDidMoveOnToNextItem = @"VLCPlaybackSer
     return band.frequency;
 }
 
-- (unsigned int)selectedEqualizerProfile
+#if TARGET_OS_IOS
+- (NSIndexPath *)selectedEqualizerProfile
 {
     /* this is a bit complex, if the eq is off, we need to return 0
      * if it is on, we need to provide the profile + 1 as the UI fakes a "Off" profile in its list */
     NSUserDefaults *userDefaults = [NSUserDefaults standardUserDefaults];
     if ([userDefaults boolForKey:kVLCSettingEqualizerProfileDisabled]) {
-        return 0;
+        return [NSIndexPath indexPathForRow:0 inSection:0];
     }
+
     unsigned int actualProfile = (unsigned int)[userDefaults integerForKey:kVLCSettingEqualizerProfile];
-    return actualProfile + 1;
+    if (![userDefaults boolForKey:kVLCCustomProfileEnabled]) {
+        return [NSIndexPath indexPathForRow:actualProfile + 1 inSection:0];
+    } else {
+        return [NSIndexPath indexPathForRow:actualProfile inSection:1];
+    }
 }
+#endif
 
 #pragma mark - AVAudioSession Notification Observers
 
@@ -1473,26 +1489,25 @@ NSString *const VLCPlaybackServicePlaybackDidMoveOnToNextItem = @"VLCPlaybackSer
     }
 
     CGFloat lastPosition = libraryMedia.progress;
-    SInt64 mediaDuration = libraryMedia.duration;
 
     if (_mediaPlayer.position < lastPosition) {
         NSInteger continuePlayback;
+
+        if ([libraryMedia isWatched]) {
+            goto bailout;
+        }
+
         if (libraryMedia.type == VLCMLMediaTypeAudio) {
             if (!libraryMedia.isPodcast) {
                 goto bailout;
             }
             continuePlayback = [[[NSUserDefaults standardUserDefaults] objectForKey:kVLCSettingContinueAudioPlayback] integerValue];
         } else {
-            if (mediaDuration < 10000 && !libraryMedia.isExternalMedia) {
-                goto bailout;
-            }
             continuePlayback = [[[NSUserDefaults standardUserDefaults] objectForKey:kVLCSettingContinuePlayback] integerValue];
         }
 
         if (continuePlayback == 1) {
-            if (lastPosition * mediaDuration > 120000.) {
-                [self setPlaybackPosition:lastPosition];
-            }
+            [self setPlaybackPosition:lastPosition];
         } else if (continuePlayback == 0) {
             NSArray<VLCAlertButton *> *buttonsAction = @[[[VLCAlertButton alloc] initWithTitle: NSLocalizedString(@"BUTTON_CANCEL", nil)
                                                                                          style: UIAlertActionStyleCancel
