@@ -19,6 +19,7 @@ protocol MediaMoreOptionsActionSheetDelegate {
     func mediaMoreOptionsActionSheetHideIcon(for option: OptionsNavigationBarIdentifier)
     func mediaMoreOptionsActionSheetHideAlertIfNecessary()
     func mediaMoreOptionsActionSheetPresentPopupView(withChild child: UIView)
+    func mediaMoreOptionsActionSheetDisplayEqualizerAlert(_ alert: UIAlertController)
     func mediaMoreOptionsActionSheetUpdateProgressBar()
     func mediaMoreOptionsActionSheetGetCurrentMedia() -> VLCMLMedia?
     func mediaMoreOptionsActionSheetDidSelectBookmark(value: Float)
@@ -30,6 +31,10 @@ protocol MediaMoreOptionsActionSheetDelegate {
     func mediaMoreOptionsActionSheetRemoveAddBookmarksView()
     func mediaMoreOptionsActionSheetDidToggleShuffle(_ mediaMoreOptionsActionSheet: MediaMoreOptionsActionSheet)
     func mediaMoreOptionsActionSheetDidTapRepeat(_ mediaMoreOptionsActionSheet: MediaMoreOptionsActionSheet)
+    func mediaMoreOptionsActionSheetPresentABRepeatView(with abView: ABRepeatView)
+    func mediaMoreOptionsActionSheetDidSelectAMark()
+    func mediaMoreOptionsActionSheetDidSelectBMark()
+    @objc optional func mediaMoreOptionsActionSheetShowPlaybackSpeedShortcut(_ displayView: Bool)
 }
 
 @objc (VLCMediaMoreOptionsActionSheet)
@@ -84,6 +89,7 @@ protocol MediaMoreOptionsActionSheetDelegate {
             playbackSpeedView.overrideUserInterfaceStyle = .dark
         }
         playbackSpeedView.delegate = self
+        playbackSpeedView.setupShortcutView()
         return playbackSpeedView
     }()
 
@@ -135,6 +141,12 @@ protocol MediaMoreOptionsActionSheetDelegate {
         return addBookmarksView
     }()
 
+    private lazy var abRepeatView: ABRepeatView = {
+        let abRepeatView = ABRepeatView(frame: CGRect(x: 0, y: 0, width: 500, height: 100))
+        abRepeatView.delegate = self
+        return abRepeatView
+    }()
+
     // MARK: - Initializers
     override init() {
         super.init()
@@ -225,7 +237,7 @@ protocol MediaMoreOptionsActionSheetDelegate {
         updateThemes()
     }
 
-    func addView(_ view: MediaPlayerActionSheetCellIdentifier) {
+    func addView(_ view: ActionSheetCellIdentifier) {
         switch view {
         case .filter:
             openOptionView(videoFiltersView)
@@ -279,6 +291,14 @@ extension MediaMoreOptionsActionSheet: PlaybackSpeedViewDelegate {
     func playbackSpeedViewHideIcon() {
         moreOptionsDelegate?.mediaMoreOptionsActionSheetHideIcon(for: .playbackSpeed)
     }
+
+    func playbackSpeedViewCanDisplayShortcutView() -> Bool {
+        return moreOptionsDelegate is AudioPlayerViewController
+    }
+
+    func playbackSpeedViewHandleShortcutSwitchChange(displayView: Bool) {
+        moreOptionsDelegate?.mediaMoreOptionsActionSheetShowPlaybackSpeedShortcut?(displayView)
+    }
 }
 
 // MARK: - SleepTimerViewDelegate
@@ -326,6 +346,10 @@ extension MediaMoreOptionsActionSheet: EqualizerViewUIDelegate {
     func equalizerViewHideIcon() {
         moreOptionsDelegate?.mediaMoreOptionsActionSheetHideIcon(for: .equalizer)
     }
+
+    func displayAlert(_ alert: UIAlertController) {
+        moreOptionsDelegate?.mediaMoreOptionsActionSheetDisplayEqualizerAlert(alert)
+    }
 }
 
 // MARK: - ChapterViewDelegate
@@ -381,6 +405,25 @@ extension MediaMoreOptionsActionSheet: BookmarksViewDelegate {
     }
 }
 
+// MARK: - ABRepeatViewDelegate
+extension MediaMoreOptionsActionSheet: ABRepeatViewDelegate {
+    func abRepeatViewDidSelectAMark() {
+        moreOptionsDelegate?.mediaMoreOptionsActionSheetDidSelectAMark()
+    }
+
+    func abRepeatViewDidSelectBMark() {
+        moreOptionsDelegate?.mediaMoreOptionsActionSheetDidSelectBMark()
+    }
+
+    func abRepeatViewShowIcon(_ option: OptionsNavigationBarIdentifier) {
+        moreOptionsDelegate?.mediaMoreOptionsActionSheetShowIcon(for: option)
+    }
+
+    func abRepeatViewHideIcon(_ option: OptionsNavigationBarIdentifier) {
+        moreOptionsDelegate?.mediaMoreOptionsActionSheetHideIcon(for: option)
+    }
+}
+
 // MARK: - MediaPlayerActionSheetDelegate
 extension MediaMoreOptionsActionSheet: MediaPlayerActionSheetDelegate {
     func mediaPlayerActionSheetHeaderTitle() -> String? {
@@ -410,7 +453,7 @@ extension MediaMoreOptionsActionSheet: MediaPlayerActionSheetDelegate {
 // MARK: - MediaPlayerActionSheetDataSource
 extension MediaMoreOptionsActionSheet: MediaPlayerActionSheetDataSource {
 
-    private func selectViewToPresent(for cell: MediaPlayerActionSheetCellIdentifier) -> UIView {
+    private func selectViewToPresent(for cell: ActionSheetCellIdentifier) -> UIView {
         switch cell {
         case .filter:
             return videoFiltersView
@@ -424,6 +467,8 @@ extension MediaMoreOptionsActionSheet: MediaPlayerActionSheetDataSource {
             return chapterView
         case .bookmarks:
             return bookmarksView
+        case .abRepeat:
+            return abRepeatView
         default:
             return mockView
         }
@@ -433,13 +478,15 @@ extension MediaMoreOptionsActionSheet: MediaPlayerActionSheetDataSource {
         var models: [ActionSheetCellModel] = []
         let isAudioPlayer: Bool = moreOptionsDelegate is AudioPlayerViewController
 
-        MediaPlayerActionSheetCellIdentifier.allCases.forEach {
+        ActionSheetCellIdentifier.allCases.forEach {
             if $0 == .chapters && currentMediaHasChapters == false {
                 // Do not show the chapters category when there are no chapters.
                 return
             }
 
-            if $0 == .addBookmarks {
+            // Do not display these options in the action sheet.
+            if $0 == .addBookmarks || $0 == .blackBackground ||
+                $0 == .playNextItem || $0 == .playlistPlayNextItem {
                 return
             }
 
@@ -454,13 +501,12 @@ extension MediaMoreOptionsActionSheet: MediaPlayerActionSheetDataSource {
                 viewToPresent: selectViewToPresent(for: $0),
                 cellIdentifier: $0
             )
+
             if $0 == .interfaceLock {
                 cellModel.accessoryType = .toggleSwitch
                 cellModel.viewToPresent = nil
             } else if $0 == .equalizer {
                 cellModel.accessoryType = .popup
-            } else if $0 == .chapters {
-                cellModel.accessoryType = .popup
             } else if $0 == .repeatShuffle {
                 cellModel.accessoryType = .none
                 cellModel.viewToPresent = mockView
